DROP PROCEDURE IF EXISTS sp_insert_opening;
DELIMITER $$
CREATE PROCEDURE sp_insert_opening(
	in vdat_opening date,
	in vint_product_id int(11),
	in vdec_quantity decimal(15,3),
	in vint_by_user_id int(11),
	out vintReturn INT)
BEGIN
	DECLARE int_next_id int;
	DECLARE int_fy int;
	DECLARE EXIT HANDLER FOR SQLEXCEPTION
	BEGIN
		SET vintReturn = 0;
		SHOW ERRORS;
		ROLLBACK;
	END;
	DECLARE EXIT HANDLER FOR SQLWARNING
	BEGIN
		SET vintReturn = 0;
		SHOW ERRORS;
		ROLLBACK;
	END;
	START TRANSACTION;
	SELECT (ifnull(MAX(int_opening_id),0)+1) into int_next_id FROM tbl_opening;
	INSERT INTO tbl_opening(
	int_opening_id, dat_opening, int_product_id, dec_quantity, int_by_user_id, dat_created, dat_modified)
	 VALUES (
	int_next_id, vdat_opening, vint_product_id, vdec_quantity, vint_by_user_id, NOW(), NOW());
	COMMIT;
SET vintReturn = int_next_id;
SELECT vintReturn;
END$$
DELIMITER ;

DROP PROCEDURE IF EXISTS sp_update_opening;
DELIMITER $$
CREATE PROCEDURE sp_update_opening(
	in vint_opening_id int(11),
	in vdat_opening date,
	in vint_product_id int(11),
	in vdec_quantity decimal(15,3),
	in vint_by_user_id int(11),
	out vintReturn INT)
BEGIN
	DECLARE EXIT HANDLER FOR SQLEXCEPTION
	BEGIN
		SET vintReturn = 0;
		SHOW ERRORS;
		ROLLBACK;
	END;
	DECLARE EXIT HANDLER FOR SQLWARNING
	BEGIN
		SET vintReturn = 0;
		SHOW ERRORS;
		ROLLBACK;
	END;
	START TRANSACTION;
	UPDATE tbl_opening set
		dat_opening=vdat_opening, int_product_id=vint_product_id, dec_quantity=vdec_quantity, int_by_user_id=vint_by_user_id, dat_modified= NOW()
	WHERE int_opening_id=vint_opening_id;
	COMMIT;
	SET vintReturn = vint_opening_id;
	SELECT vintReturn;
END$$
DELIMITER ;

DROP PROCEDURE IF EXISTS sp_delete_opening;
DELIMITER $$
CREATE PROCEDURE sp_delete_opening(
	in vint_opening_id INT,
	out vintReturn INT)
BEGIN
	DECLARE int_ref_count int;
	DECLARE EXIT HANDLER FOR SQLEXCEPTION
	BEGIN
		SET vintReturn = 0;
		SHOW ERRORS;
		ROLLBACK;
	END;
	DECLARE EXIT HANDLER FOR SQLWARNING
	BEGIN
		SET vintReturn = 0;
		SHOW ERRORS;
		ROLLBACK;
	END;
	START TRANSACTION;
		SELECT SUM(int_count) INTO int_ref_count FROM (
		(Select count(int_source_opening_id) AS int_count FROM tbl_stock_movement WHERE int_source_opening_id=vint_opening_id)
		 UNION ALL
		(Select count(int_target_opening_id) AS int_count FROM tbl_stock_movement WHERE int_target_opening_id=vint_opening_id)
		 ) qry; 
		IF(int_ref_count> 0) THEN 
			SET vintReturn = 0;
		ELSE 
			DELETE FROM tbl_opening WHERE int_opening_id=vint_opening_id;
			SET vintReturn = vint_opening_id;
		END IF;
	COMMIT;
	SELECT vintReturn;
END$$
DELIMITER ;
