DROP PROCEDURE IF EXISTS sp_insert_products;
DELIMITER $$
CREATE PROCEDURE sp_insert_products(
	in vtxt_product_name varchar(100),
	in vtxt_hsn_code varchar(25),
	in vint_by_user_id int(11),
	out vintReturn INT)
BEGIN
	DECLARE int_next_id int;
	DECLARE int_fy int;
	DECLARE EXIT HANDLER FOR SQLEXCEPTION
	BEGIN
		SET vintReturn = 0;
		SHOW ERRORS;
		ROLLBACK;
	END;
	DECLARE EXIT HANDLER FOR SQLWARNING
	BEGIN
		SET vintReturn = 0;
		SHOW ERRORS;
		ROLLBACK;
	END;
	START TRANSACTION;
	SELECT (ifnull(MAX(int_product_id),0)+1) into int_next_id FROM tbl_products;
	INSERT INTO tbl_products(
	int_product_id, txt_product_name, txt_hsn_code, int_by_user_id, dat_created, dat_modified)
	 VALUES (
	int_next_id, vtxt_product_name, vtxt_hsn_code, vint_by_user_id, NOW(), NOW());
	COMMIT;
SET vintReturn = int_next_id;
SELECT vintReturn;
END$$
DELIMITER ;

DROP PROCEDURE IF EXISTS sp_update_products;
DELIMITER $$
CREATE PROCEDURE sp_update_products(
	in vint_product_id int(11),
	in vtxt_product_name varchar(100),
	in vtxt_hsn_code varchar(25),
	in vint_by_user_id int(11),
	out vintReturn INT)
BEGIN
	DECLARE EXIT HANDLER FOR SQLEXCEPTION
	BEGIN
		SET vintReturn = 0;
		SHOW ERRORS;
		ROLLBACK;
	END;
	DECLARE EXIT HANDLER FOR SQLWARNING
	BEGIN
		SET vintReturn = 0;
		SHOW ERRORS;
		ROLLBACK;
	END;
	START TRANSACTION;
	UPDATE tbl_products set
		txt_product_name=vtxt_product_name, txt_hsn_code=vtxt_hsn_code, int_by_user_id=vint_by_user_id,  dat_modified= NOW()
	WHERE int_product_id=vint_product_id;
	COMMIT;
	SET vintReturn = vint_product_id;
	SELECT vintReturn;
END$$
DELIMITER ;

DROP PROCEDURE IF EXISTS sp_delete_products;
DELIMITER $$
CREATE PROCEDURE sp_delete_products(
	in vint_product_id INT,
	out vintReturn INT)
BEGIN
	DECLARE int_ref_count int;
	DECLARE EXIT HANDLER FOR SQLEXCEPTION
	BEGIN
		SET vintReturn = 0;
		SHOW ERRORS;
		ROLLBACK;
	END;
	DECLARE EXIT HANDLER FOR SQLWARNING
	BEGIN
		SET vintReturn = 0;
		SHOW ERRORS;
		ROLLBACK;
	END;
	START TRANSACTION;
		SELECT SUM(int_count) INTO int_ref_count FROM (
		(Select count(int_product_id) AS int_count FROM tbl_opening WHERE int_product_id=vint_product_id)
		 UNION ALL
		(Select count(int_product_id) AS int_count FROM tbl_purchase_order WHERE int_product_id=vint_product_id)
		 UNION ALL
		(Select count(int_product_id) AS int_count FROM tbl_sales_order WHERE int_product_id=vint_product_id)
		 UNION ALL
		(Select count(int_product_id) AS int_count FROM tbl_stock_movement WHERE int_product_id=vint_product_id)
		 ) qry; 
		IF(int_ref_count> 0) THEN 
			SET vintReturn = 0;
		ELSE 
			DELETE FROM tbl_products WHERE int_product_id=vint_product_id;
			SET vintReturn = vint_product_id;
		END IF;
	COMMIT;
	SELECT vintReturn;
END$$
DELIMITER ;
