DROP PROCEDURE IF EXISTS sp_insert_stock_movement;
DELIMITER $$
CREATE PROCEDURE sp_insert_stock_movement(
	in vdat_transaction date,
	in vint_product_id int(11),
	in vdec_quantity decimal(15,3),
	in vint_source_opening_id int(11),
	in vint_source_purchase_id int(11),
	in vint_source_storage_unit_id int(11),
	in vint_source_production_id int(11),
	in vtxt_source_drum_tag varchar(25),
	in vint_target_opening_id int(11),
	in vint_target_purchase_id int(11),
	in vint_target_sales_order_id int(11),
	in vint_target_storage_unit_id int(11),
	in vint_target_production_id int(11),
	in vtxt_target_drum_tag varchar(25),
	in vtxt_remarks varchar(250),
	in vint_by_user_id int(11),
	out vintReturn INT)
BEGIN
	DECLARE int_next_id int;
	DECLARE int_fy int;
	DECLARE int_vrole_type int;
	DECLARE int_vverified int;
	DECLARE EXIT HANDLER FOR SQLEXCEPTION
	BEGIN
		SET vintReturn = 0;
		SHOW ERRORS;
		ROLLBACK;
	END;
	DECLARE EXIT HANDLER FOR SQLWARNING
	BEGIN
		SET vintReturn = 0;
		SHOW ERRORS;
		ROLLBACK;
	END;
	START TRANSACTION;
	SELECT int_role_type INTO int_vrole_type FROM tbl_users WHERE int_user_id=vint_by_user_id;
	IF int_vrole_type=1 THEN
		SET int_vverified =1;
	ELSE
		SET int_vverified =0;
	END IF;
	SELECT (ifnull(MAX(int_stock_movement_id),0)+1) into int_next_id FROM tbl_stock_movement;
	INSERT INTO tbl_stock_movement(
	int_stock_movement_id, dat_transaction, int_product_id, dec_quantity, int_source_opening_id, int_source_purchase_id, int_source_storage_unit_id, int_source_production_id, txt_source_drum_tag, int_target_opening_id, int_target_purchase_id, int_target_sales_order_id, int_target_storage_unit_id, int_target_production_id, txt_target_drum_tag, txt_remarks, int_verified, int_by_user_id, dat_created, dat_modified)
	 VALUES (
	int_next_id, vdat_transaction, vint_product_id, vdec_quantity, vint_source_opening_id, vint_source_purchase_id, vint_source_storage_unit_id, vint_source_production_id, vtxt_source_drum_tag, vint_target_opening_id, vint_target_purchase_id, vint_target_sales_order_id, vint_target_storage_unit_id, vint_target_production_id, vtxt_target_drum_tag, vtxt_remarks, int_vverified, vint_by_user_id, NOW(), NOW());
	COMMIT;
SET vintReturn = int_next_id;
SELECT vintReturn;
END$$
DELIMITER ;

DROP PROCEDURE IF EXISTS sp_update_stock_movement;
DELIMITER $$
CREATE PROCEDURE sp_update_stock_movement(
	in vint_stock_movement_id int(11),
	in vdat_transaction date,
	in vint_product_id int(11),
	in vdec_quantity decimal(15,3),
	in vint_source_opening_id int(11),
	in vint_source_purchase_id int(11),
	in vint_source_storage_unit_id int(11),
	in vint_source_production_id int(11),
	in vtxt_source_drum_tag varchar(25),
	in vint_target_opening_id int(11),
	in vint_target_purchase_id int(11),
	in vint_target_sales_order_id int(11),
	in vint_target_storage_unit_id int(11),
	in vint_target_production_id int(11),
	in vtxt_target_drum_tag varchar(25),
	in vtxt_remarks varchar(250),
	in vint_by_user_id int(11),
	out vintReturn INT)
BEGIN
	DECLARE int_vrole_type int;
	DECLARE int_vverified int;
	DECLARE EXIT HANDLER FOR SQLEXCEPTION
	BEGIN
		SET vintReturn = 0;
		SHOW ERRORS;
		ROLLBACK;
	END;
	DECLARE EXIT HANDLER FOR SQLWARNING
	BEGIN
		SET vintReturn = 0;
		SHOW ERRORS;
		ROLLBACK;
	END;
	START TRANSACTION;
	SELECT int_role_type INTO int_vrole_type FROM tbl_users WHERE int_user_id=vint_by_user_id;
	IF int_vrole_type=1 THEN
		SET int_vverified =1;
	ELSE
		SET int_vverified =0;
	END IF;
	UPDATE tbl_stock_movement set
		dat_transaction=vdat_transaction, int_product_id=vint_product_id, dec_quantity=vdec_quantity, int_source_opening_id=vint_source_opening_id, int_source_purchase_id=vint_source_purchase_id, int_source_storage_unit_id=vint_source_storage_unit_id, int_source_production_id=vint_source_production_id, txt_source_drum_tag=vtxt_source_drum_tag, int_target_opening_id=vint_target_opening_id, int_target_purchase_id=vint_target_purchase_id, int_target_sales_order_id=vint_target_sales_order_id, int_target_storage_unit_id=vint_target_storage_unit_id, int_target_production_id=vint_target_production_id, txt_target_drum_tag=vtxt_target_drum_tag, txt_remarks=vtxt_remarks,int_verified=int_vverified,int_by_user_id=vint_by_user_id, dat_modified= NOW()
	WHERE int_stock_movement_id=vint_stock_movement_id;
	COMMIT;
	SET vintReturn = vint_stock_movement_id;
	SELECT vintReturn;
END$$
DELIMITER ;

DROP PROCEDURE IF EXISTS sp_delete_stock_movement;
DELIMITER $$
CREATE PROCEDURE sp_delete_stock_movement(
	in vint_stock_movement_id INT,
	out vintReturn INT)
BEGIN
	DECLARE int_ref_count int;
	DECLARE EXIT HANDLER FOR SQLEXCEPTION
	BEGIN
		SET vintReturn = 0;
		SHOW ERRORS;
		ROLLBACK;
	END;
	DECLARE EXIT HANDLER FOR SQLWARNING
	BEGIN
		SET vintReturn = 0;
		SHOW ERRORS;
		ROLLBACK;
	END;
	START TRANSACTION;
		DELETE FROM tbl_stock_movement WHERE int_stock_movement_id=vint_stock_movement_id;
		SET vintReturn = vint_stock_movement_id;
	COMMIT;
	SELECT vintReturn;
END$$
DELIMITER ;
