DROP PROCEDURE IF EXISTS sp_insert_storage_units;
DELIMITER $$
CREATE PROCEDURE sp_insert_storage_units(
	in vtxt_storage varchar(100),
	in vint_storage_capacity int(11),
	in vint_by_user_id int(11),
	out vintReturn INT)
BEGIN
	DECLARE int_next_id int;
	DECLARE int_fy int;
	DECLARE EXIT HANDLER FOR SQLEXCEPTION
	BEGIN
		SET vintReturn = 0;
		SHOW ERRORS;
		ROLLBACK;
	END;
	DECLARE EXIT HANDLER FOR SQLWARNING
	BEGIN
		SET vintReturn = 0;
		SHOW ERRORS;
		ROLLBACK;
	END;
	START TRANSACTION;
	SELECT (ifnull(MAX(int_storage_unit_id),0)+1) into int_next_id FROM tbl_storage_units;
	INSERT INTO tbl_storage_units(
	int_storage_unit_id, txt_storage, int_storage_capacity, int_by_user_id, dat_created, dat_modified)
	 VALUES (
	int_next_id, vtxt_storage, vint_storage_capacity, vint_by_user_id, NOW(), NOW());
	COMMIT;
SET vintReturn = int_next_id;
SELECT vintReturn;
END$$
DELIMITER ;

DROP PROCEDURE IF EXISTS sp_update_storage_units;
DELIMITER $$
CREATE PROCEDURE sp_update_storage_units(
	in vint_storage_unit_id int(11),
	in vtxt_storage varchar(100),
	in vint_storage_capacity int(11),
	in vint_by_user_id int(11),
	out vintReturn INT)
BEGIN
	DECLARE EXIT HANDLER FOR SQLEXCEPTION
	BEGIN
		SET vintReturn = 0;
		SHOW ERRORS;
		ROLLBACK;
	END;
	DECLARE EXIT HANDLER FOR SQLWARNING
	BEGIN
		SET vintReturn = 0;
		SHOW ERRORS;
		ROLLBACK;
	END;
	START TRANSACTION;
	UPDATE tbl_storage_units set
		txt_storage=vtxt_storage, int_storage_capacity=vint_storage_capacity, int_by_user_id=vint_by_user_id, dat_modified= NOW()
	WHERE int_storage_unit_id=vint_storage_unit_id;
	COMMIT;
	SET vintReturn = vint_storage_unit_id;
	SELECT vintReturn;
END$$
DELIMITER ;

DROP PROCEDURE IF EXISTS sp_delete_storage_units;
DELIMITER $$
CREATE PROCEDURE sp_delete_storage_units(
	in vint_storage_unit_id INT,
	out vintReturn INT)
BEGIN
	DECLARE int_ref_count int;
	DECLARE EXIT HANDLER FOR SQLEXCEPTION
	BEGIN
		SET vintReturn = 0;
		SHOW ERRORS;
		ROLLBACK;
	END;
	DECLARE EXIT HANDLER FOR SQLWARNING
	BEGIN
		SET vintReturn = 0;
		SHOW ERRORS;
		ROLLBACK;
	END;
	START TRANSACTION;
		SELECT SUM(int_count) INTO int_ref_count FROM (
		(Select count(int_source_storage_unit_id) AS int_count FROM tbl_stock_movement WHERE int_source_storage_unit_id=vint_storage_unit_id)
		 UNION ALL
		(Select count(int_target_storage_unit_id) AS int_count FROM tbl_stock_movement WHERE int_target_storage_unit_id=vint_storage_unit_id)
		 ) qry; 
		IF(int_ref_count> 0) THEN 
			SET vintReturn = 0;
		ELSE 
			DELETE FROM tbl_storage_units WHERE int_storage_unit_id=vint_storage_unit_id;
			SET vintReturn = vint_storage_unit_id;
		END IF;
	COMMIT;
	SELECT vintReturn;
END$$
DELIMITER ;
